@@ -57,19 +57,17 @@ static time_t
 my_timegm(struct tm *tm)
 {
     time_t ret;
-    char *tz;
+    GDateTime *initial_date;
+
+    initial_date = g_date_time_new_utc(tm->tm_year + 1900,
+                                       tm->tm_mon + 1,
+                                       tm->tm_mday,
+                                       tm->tm_hour,
+                                       tm->tm_min,
+                                       tm->tm_sec);
+    ret = g_date_time_to_unix(initial_date);
+    g_date_time_unref(initial_date);
 
-    tz = g_strdup(g_getenv("TZ"));
-    g_setenv("TZ", "", 1);
-    tzset();
-    ret = mktime(tm);
-    if (tz) {
-        g_setenv("TZ", tz, 1);
-        g_free(tz);
-    }
-    else
-        g_unsetenv("TZ");
-    tzset();
     return ret;
 }
 
@@ -79,7 +77,7 @@ my_timegm(struct tm *tm)
  * date format (before the new API, 2.x).
  */
 static gchar *
-remove_timezone_offset(gchar *date)
+remove_timezone_offset(const gchar *date)
 {
     GRegex *re = NULL;
     const gchar *pattern = "[+-][0-9]{2}:[0-9]{2}";
@@ -89,20 +87,13 @@ remove_timezone_offset(gchar *date)
     if (re != NULL && g_regex_match(re, date, 0, NULL)) {
         res = g_regex_replace(re, date, -1, 0, "Z", 0, NULL);
     } else {
-        res = date;
+        res = g_strdup(date);
     }
     g_regex_unref(re);
     return res;
 }
 
 
-static gdouble
-extract_double(gchar *str)
-{
-    return g_ascii_strtod (str, NULL);
-}
-
-
 xml_time *
 get_timeslice(xml_weather *wd,
               const time_t start_t,
@@ -141,8 +132,10 @@ get_astro(const GArray *astrodata,
     if (G_UNLIKELY(astrodata == NULL))
         return NULL;
 
+    weather_debug("day_t=%s", format_date(day_t, NULL,TRUE));
     for (i = 0; i < astrodata->len; i++) {
         astro = g_array_index(astrodata, xml_astro *, i);
+        weather_debug("astro->day=%s", format_date(astro->day, NULL,TRUE));
         if (astro && astro->day == day_t) {
             if (index != NULL)
                 *index = i;
@@ -155,7 +148,7 @@ get_astro(const GArray *astrodata,
 
 time_t
 parse_timestring(const gchar *ts,
-                 gchar *format,
+                 const gchar *format,
                  gboolean local) {
     time_t t;
     struct tm tm;
@@ -189,7 +182,8 @@ parse_timestring(const gchar *ts,
 
 
 static const gchar *
-parse_moonposition (gdouble pos) {
+parse_moonposition (gdouble pos_in) {
+    gdouble pos = pos_in / 360.0 * 100.0;
     if (pos < 0.0 || pos > 100.0)
         return "Unknown";
     if (pos <= 12.5)
@@ -422,82 +416,261 @@ parse_weather(xmlNode *cur_node,
 }
 
 
-static xml_astro *
-parse_astro_time(xmlNode *cur_node)
+/*
+ * Look at https://docs.api.met.no/doc/formats/SunriseJSON for information
+ * of elements and attributes to expect.
+ */
+gboolean
+parse_astrodata_sun(json_object *cur_node,
+                    GArray *astrodata)
 {
-    xmlNode *child_node;
     xml_astro *astro;
-    gchar *date, *sunrise, *sunset, *moonrise, *moonset;
+    json_object *jwhen, *jinterval, *jproperties, *jdate, *jsunrise,
+                *jsunrise_time, *jsunset, *jsunset_time,
+                *jsolarnoon, *jsolarmidnight, *jdisc_centre_elevation;
+    const gchar day_format[]="%Y-%m-%dT%H:%M:%SZ";
+    const gchar sun_format[]="%Y-%m-%dT%H:%MZ";
+    const gchar *date;
+    gchar *time;
     gboolean sun_rises = FALSE, sun_sets = FALSE;
-    gboolean moon_rises = FALSE, moon_sets = FALSE;
-    gdouble moonposition;
 
     astro = g_slice_new0(xml_astro);
     if (G_UNLIKELY(astro == NULL))
-        return NULL;
+        return FALSE;
 
-    date = PROP(cur_node, "date");
-    astro->day = parse_timestring(date, "%Y-%m-%d", TRUE);
-    xmlFree(date);
+    g_assert(astrodata != NULL);
+    if (G_UNLIKELY(astrodata == NULL))
+        return FALSE;
 
-    for (child_node = cur_node->children; child_node;
-         child_node = child_node->next) {
-        if (child_node->type == XML_ELEMENT_NODE) {
-            if (NODE_IS_TYPE(child_node, "sunrise")) {
-                sunrise = remove_timezone_offset(PROP(child_node, "time"));
-                astro->sunrise = parse_timestring(sunrise, NULL, TRUE);
-                xmlFree(sunrise);
-                sun_rises = TRUE;
-            }
+    jwhen = json_object_object_get(cur_node, "when");
+    if (G_UNLIKELY(jwhen == NULL))
+        return FALSE;
 
-            if (NODE_IS_TYPE(child_node, "moonset")) {
-                moonset = remove_timezone_offset(PROP(child_node, "time"));
-                astro->moonset = parse_timestring(moonset, NULL, TRUE);
-                xmlFree(moonset);
-                moon_sets = TRUE;
-            }
+    jinterval = json_object_object_get(jwhen, "interval");
+    if (G_UNLIKELY(jinterval == NULL))
+        return FALSE;
+    if (G_UNLIKELY(json_object_array_length(jinterval)!=2))
+        return FALSE;
 
-            if (NODE_IS_TYPE(child_node, "sunset")) {
-                sunset = remove_timezone_offset(PROP(child_node, "time"));
-                astro->sunset = parse_timestring(sunset, NULL, TRUE);
-                xmlFree(sunset);
-                sun_sets = TRUE;
-            }
+    jdate = json_object_array_get_idx(jinterval, 0);
+    if (G_UNLIKELY(jdate == NULL))
+        return FALSE;
 
-            if (NODE_IS_TYPE(child_node, "moonrise")) {
-                moonrise = remove_timezone_offset(PROP(child_node, "time"));
-                astro->moonrise = parse_timestring(moonrise, NULL, TRUE);
-                xmlFree(moonrise);
-                moon_rises = TRUE;
-            }
+    date = json_object_get_string(jdate);
+    if (G_UNLIKELY(date == NULL))
+        return FALSE;
 
-            if (NODE_IS_TYPE(child_node, "moonposition")) {
-                moonposition = extract_double(PROP(child_node, "phase"));
-                if (astro->moon_phase) {
-                    g_free (astro->moon_phase);
-                }
-                astro->moon_phase = g_strdup(parse_moonposition(moonposition));
-            }
+    /* use time info at center of day interval */
+    astro->day = day_at_midnight(parse_timestring(date, day_format, FALSE) + 12 * 3600, 0);
+    weather_debug("sun: astro->day=%s\n",
+                  format_date(astro->day, day_format,TRUE)); 
 
-            if (NODE_IS_TYPE(child_node, "solarnoon")) {
-                astro->solarnoon_elevation = extract_double(PROP(child_node, "elevation"));
-            }
+    jproperties = json_object_object_get(cur_node, "properties");
+    if (G_UNLIKELY(jproperties == NULL))
+        return FALSE;
 
-            if (NODE_IS_TYPE(child_node, "solarmidnight")) {
-                astro->solarmidnight_elevation = extract_double(PROP(child_node, "elevation"));
-            }
-        }
+    jsunrise = json_object_object_get(jproperties, "sunrise");
+    if (G_UNLIKELY(jsunrise == NULL))
+        return FALSE;
+
+    jsunrise_time = json_object_object_get(jsunrise, "time");
+    if (G_UNLIKELY(jsunrise_time == NULL)) {
+        weather_debug("sunrise time not found");
+    } else {
+        date = json_object_get_string(jsunrise_time);
+        if (G_UNLIKELY(date == NULL))
+            return FALSE;
+        time = remove_timezone_offset(date);
+        astro->sunrise= parse_timestring(time, sun_format, TRUE);
+        sun_rises = TRUE;
+        weather_debug("astro->sunrise=%s\n",
+                      format_date(astro->sunrise, NULL,TRUE));
+        g_free(time);
     }
 
+    jsunset = json_object_object_get(jproperties, "sunset");
+    if (G_UNLIKELY(jsunset == NULL))
+        return FALSE;
+
+    jsunset_time = json_object_object_get(jsunset, "time");
+    if (G_UNLIKELY(jsunset_time == NULL)) {
+        weather_debug("sunset time not found");
+    } else {
+        date = json_object_get_string(jsunset_time);
+        if (G_UNLIKELY(date == NULL))
+            return FALSE;
+        time = remove_timezone_offset(date);
+        astro->sunset= parse_timestring(time, sun_format, TRUE);
+        sun_sets = TRUE;
+        weather_debug("astro->sunset=%s\n",
+                      format_date(astro->sunset, NULL,TRUE));
+        g_free(time);
+    }
+
+    jsolarnoon = json_object_object_get(jproperties, "solarnoon");
+    if (G_UNLIKELY(jsolarnoon == NULL))
+        return FALSE;
+
+    jdisc_centre_elevation = json_object_object_get(jsolarnoon, "disc_centre_elevation");
+    if (G_UNLIKELY(jdisc_centre_elevation == NULL))
+        return FALSE;
+
+    astro->solarnoon_elevation = json_object_get_double(jdisc_centre_elevation);
+    weather_debug("astro->solarnoon_elevation=%f\n",
+                  astro->solarnoon_elevation);
+
+    jsolarmidnight = json_object_object_get(jproperties, "solarmidnight");
+    if (G_UNLIKELY(jsolarmidnight == NULL))
+        return FALSE;
+
+    jdisc_centre_elevation = json_object_object_get(jsolarmidnight, "disc_centre_elevation");
+    if (G_UNLIKELY(jdisc_centre_elevation == NULL))
+        return FALSE;
+
+    astro->solarmidnight_elevation = json_object_get_double(jdisc_centre_elevation);
+    weather_debug("astro->solarmidnight_elevation=%f\n",
+                  astro->solarmidnight_elevation);
+
     if (sun_rises)
         astro->sun_never_rises = FALSE;
     else
         astro->sun_never_rises = TRUE;
+
     if (sun_sets)
         astro->sun_never_sets = FALSE;
     else
         astro->sun_never_sets = TRUE;
 
+    merge_astro(astrodata, astro);
+    xml_astro_free(astro);
+    return TRUE;
+}
+
+
+/*
+ * Look at https://docs.api.met.no/doc/formats/SunriseJSON for information
+ * of elements and attributes to expect.
+ */
+gboolean
+parse_astrodata_moon(json_object *cur_node,
+                     GArray *astrodata)
+{
+    xml_astro *astro;
+    json_object *jwhen, *jinterval, *jproperties, *jdate, *jmoonrise,
+                *jmoonrise_time, *jmoonset,  *jmoonset_time, *jmoonphase;
+    time_t day;
+    guint index;
+    const gchar day_format[]="%Y-%m-%dT%H:%M:%SZ";
+    const gchar moon_format[]="%Y-%m-%dT%H:%MZ";
+    const gchar *date;
+    gchar *time;
+    gboolean moon_rises = FALSE, moon_sets = FALSE;
+
+    g_assert(astrodata != NULL);
+    if (G_UNLIKELY(astrodata == NULL))
+        return FALSE;
+
+    jwhen = json_object_object_get(cur_node, "when");
+    if (G_UNLIKELY(jwhen == NULL)) {
+        weather_debug("when not found" );
+        return FALSE;
+    }
+
+    jinterval = json_object_object_get(jwhen, "interval");
+    if (G_UNLIKELY(jinterval == NULL)) {
+        weather_debug("interval not found" );
+        return FALSE;
+    }
+    if (G_UNLIKELY(json_object_array_length(jinterval)!=2)) {
+        weather_debug("interval length is %d instead of %d",
+                      json_object_array_length(jinterval));
+        return FALSE;
+    }
+
+    jdate = json_object_array_get_idx(jinterval, 0);
+    if (G_UNLIKELY(jdate == NULL)) {
+        weather_debug("jdate empty" );
+        return FALSE;
+    }
+
+    date = json_object_get_string(jdate);
+    if (G_UNLIKELY(date == NULL)) {
+        weather_debug("date not found" );
+        return FALSE;
+    }
+
+    /* use time info at center of day interval */
+    day = day_at_midnight(parse_timestring(date, day_format, FALSE) + 12 * 3600, 0);
+    /* this data seems weird */
+    astro = get_astro(astrodata, day, &index);
+    if (G_UNLIKELY(astro == NULL)) {
+        weather_debug("no sun astrodata for day=%s\n",
+                      format_date(day, day_format,FALSE));
+        return FALSE;
+    }
+
+    astro->day=day;
+    weather_debug("moon: astro->day=%s\n", format_date(astro->day, day_format,TRUE));
+
+    jproperties = json_object_object_get(cur_node, "properties");
+    if (G_UNLIKELY(jproperties == NULL)) {
+        weather_debug("properties not found" );
+        return FALSE;
+    }
+
+    jmoonrise = json_object_object_get(jproperties, "moonrise");
+    if (G_UNLIKELY(jmoonrise == NULL)) {
+        weather_debug("moonrise not found" );
+        return FALSE;
+    }
+
+    jmoonrise_time = json_object_object_get(jmoonrise, "time");
+    if (G_UNLIKELY(jmoonrise_time == NULL)) {
+        weather_debug("moonrise time not found" );
+    } else {
+        date = json_object_get_string(jmoonrise_time);
+        if (G_UNLIKELY(date == NULL)) {
+            weather_debug("jmoonrise_time empty" );
+            return FALSE;
+        }
+        time = remove_timezone_offset(date);
+        astro->moonrise= parse_timestring(time, moon_format, TRUE);
+        moon_rises = TRUE;
+        weather_debug("astro->moonrise=%s\n",
+                      format_date(astro->moonrise, NULL,TRUE));
+        g_free(time);
+    }
+
+    jmoonset = json_object_object_get(jproperties, "moonset");
+    if (G_UNLIKELY(jmoonset == NULL)) {
+        weather_debug("moonset not found" );
+        return FALSE;
+    }
+    jmoonset_time = json_object_object_get(jmoonset, "time");
+    if (G_UNLIKELY(jmoonset_time == NULL)) {
+        weather_debug("moonset time not found" );
+    } else {
+        date = json_object_get_string(jmoonset_time);
+        if (G_UNLIKELY(date == NULL)) {
+            weather_debug("moonset time empty" );
+            return FALSE;
+        }
+        time = remove_timezone_offset(date);
+        astro->moonset= parse_timestring(time, moon_format, TRUE);
+        moon_sets = TRUE;
+        weather_debug("astro->moonset=%s\n",
+                      format_date(astro->moonset, NULL,TRUE));
+        g_free(time);
+    }
+
+    jmoonphase = json_object_object_get(jproperties, "moonphase");
+    if (G_UNLIKELY(jmoonphase == NULL)) {
+        weather_debug("moonphase not found" );
+        return FALSE;
+    }
+    astro->moon_phase =g_strdup(parse_moonposition( json_object_get_double(jmoonphase)));
+    weather_debug("astro->moonphase=%s\n",astro->moon_phase);
+
     if (moon_rises)
         astro->moon_never_rises = FALSE;
     else
@@ -506,38 +679,8 @@ parse_astro_time(xmlNode *cur_node)
         astro->moon_never_sets = FALSE;
     else
         astro->moon_never_sets = TRUE;
-    return astro;
-}
 
-
-/*
- * Look at https://api.met.no/weatherapi/sunrise/2.0/schema for information
- * of elements and attributes to expect.
- */
-gboolean
-parse_astrodata(xmlNode *cur_node,
-                GArray *astrodata)
-{
-    xmlNode *child_node;
-    xml_astro *astro;
-
-    g_assert(astrodata != NULL);
-    if (G_UNLIKELY(astrodata == NULL))
-        return FALSE;
-
-    g_assert(cur_node != NULL);
-    if (G_UNLIKELY(cur_node == NULL ||
-        !NODE_IS_TYPE(cur_node, "location")))
-        return FALSE;
-
-    for (child_node = cur_node->children; child_node;
-         child_node = child_node->next)
-        if (NODE_IS_TYPE(child_node, "time")) {
-            if ((astro = parse_astro_time(child_node))) {
-                merge_astro(astrodata, astro);
-                xml_astro_free(astro);
-            }
-        }
+    merge_astro(astrodata, astro);
     return TRUE;
 }
 
@@ -664,6 +807,19 @@ get_xml_document(SoupMessage *msg)
     return NULL;
 }
 
+json_object *
+get_json_tree(SoupMessage *msg)
+{
+    json_object *res=NULL;
+    enum json_tokener_error err;
+
+    if (G_LIKELY(msg && msg->response_body && msg->response_body->data)) {
+        res =  json_tokener_parse_verbose(msg->response_body->data, &err);
+        if (err != json_tokener_success)
+            g_warning("get_json_tree: error =%d",err);
+    }
+    return res;
+}
 
 gpointer
 parse_xml_document(SoupMessage *msg,
