@@ -23,6 +23,7 @@
 #include <gtk/gtk.h>
 #include <libxml/parser.h>
 #include <libsoup/soup.h>
+#include <json-c/json_tokener.h>
 
 #define DATA_EXPIRY_TIME (24 * 3600)
 
@@ -86,6 +87,8 @@ typedef struct {
     time_t sunset;
     gboolean sun_never_rises;
     gboolean sun_never_sets;
+    gdouble solarnoon_elevation;
+    gdouble solarmidnight_elevation;
 
     time_t moonrise;
     time_t moonset;
@@ -125,13 +128,17 @@ xml_weather *make_weather_data(void);
 xml_time *make_timeslice(void);
 
 time_t parse_timestring(const gchar *ts,
-                        gchar *format,
+                        const gchar *format,
                         gboolean local);
 
 gboolean parse_weather(xmlNode *cur_node,
                        xml_weather *wd);
 
-xml_astro *parse_astro(xmlNode *cur_node);
+gboolean parse_astrodata_sun(json_object *cur_node,
+                             GArray *astrodata);
+
+gboolean parse_astrodata_moon(json_object *cur_node,
+                              GArray *astrodata);
 
 xml_geolocation *parse_geolocation(xmlNode *cur_node);
 
@@ -152,6 +159,8 @@ xml_astro *get_astro(const GArray *astrodata,
 
 xmlDoc *get_xml_document(SoupMessage *msg);
 
+json_object *get_json_tree(SoupMessage *msg);
+
 gpointer parse_xml_document(SoupMessage *msg,
                             XmlParseFunc parse_func);
 
