@@ -92,8 +92,7 @@ static void
 gtk_scrollbox_labels_free(GtkScrollbox *self)
 {
     /* free all the labels */
-    g_list_foreach(self->labels, (GFunc) g_object_unref, NULL);
-    g_list_free(self->labels);
+    g_list_free_full(self->labels, g_object_unref);
     self->labels = NULL;
 }
 
@@ -472,8 +471,7 @@ gtk_scrollbox_clear_new(GtkScrollbox *self)
     g_return_if_fail(GTK_IS_SCROLLBOX(self));
 
     /* free all the new labels */
-    g_list_foreach(self->labels_new, (GFunc) g_object_unref, NULL);
-    g_list_free(self->labels_new);
+    g_list_free_full(self->labels_new, g_object_unref);
     self->labels_new = NULL;
 }
 
