@@ -245,9 +245,9 @@ logo_fetched(SoupSession *session,
         gint scale_factor;
         if (!g_file_set_contents(path, msg->response_body->data,
                                  msg->response_body->length, &error)) {
-            g_warning(_("Error downloading met.no logo image to %s, "
-                        "reason: %s\n"), path,
-                      error ? error->message : _("unknown"));
+            g_warning("Error downloading met.no logo image to %s, "
+                      "reason: %s\n", path,
+                      error ? error->message : "unknown");
             g_error_free(error);
             g_free(path);
             return;
@@ -570,7 +570,7 @@ create_summary_tab(plugin_data *data)
     APPEND_TEXT_ITEM(_("Cloudiness"), CLOUDINESS);
 
     /* credits */
-    gdk_rgba_parse(&lnk_color, "#0000ff");
+    gdk_rgba_parse(&lnk_color, "#1A5FB4");
     ltag_img = gtk_text_buffer_create_tag(buffer, "lnk0", "foreground-rgba",
                                           &lnk_color, NULL);
     ltag_metno = gtk_text_buffer_create_tag(buffer, "lnk1", "foreground-rgba",
