@@ -198,12 +198,7 @@ make_label(const plugin_data *data,
 static update_info *
 make_update_info(const guint check_interval)
 {
-    update_info *upi;
-
-    upi = g_slice_new0(update_info);
-    if (G_UNLIKELY(upi == NULL))
-        return NULL;
-
+    update_info *upi = g_slice_new0(update_info);
     memset(&upi->last, 0, sizeof(upi->last));
     upi->next = time(NULL);
     upi->check_interval = check_interval;
@@ -711,7 +706,7 @@ update_handler(gpointer user_data)
                 day_t = day_at_midnight(now_t, day);
                 now_tm = *localtime(&day_t);
                 /* build url */
-                url = g_strdup_printf("https://api.met.no/weatherapi"
+                url = g_strdup_printf("https://aa062reffgwvo1efa.api.met.no/weatherapi"
                                       "/sunrise/3.0/sun?lat=%s&lon=%s&"
                                       "date=%04d-%02d-%02d&"
                                       "offset=%s",
@@ -735,7 +730,7 @@ update_handler(gpointer user_data)
             for (day = 0; day < astro_forecast_days; day++) {
                 day_t = day_at_midnight(now_t, day);
                 now_tm = *localtime(&day_t);
-                url = g_strdup_printf("https://api.met.no/weatherapi"
+                url = g_strdup_printf("https://aa062reffgwvo1efa.api.met.no/weatherapi"
                                       "/sunrise/3.0/moon?lat=%s&lon=%s&"
                                       "date=%04d-%02d-%02d&"
                                       "offset=%s",
@@ -763,7 +758,7 @@ update_handler(gpointer user_data)
         data->weather_update->started = TRUE;
 
         /* build url */
-        url = g_strdup_printf("https://api.met.no"
+        url = g_strdup_printf("https://aa062reffgwvo1efa.api.met.no"
                               "/weatherapi/locationforecast/%s/"
                               "classic?lat=%s&lon=%s&altitude=%d",
                               api_version,
@@ -1320,7 +1315,7 @@ read_cache_file(plugin_data *data)
     xml_time *timeslice = NULL;
     xml_location *loc = NULL;
     xml_astro *astro = NULL;
-    time_t now_t = time(NULL), cache_date_t;
+    time_t cache_date_t;
     gchar *file, *locname = NULL, *lat = NULL, *lon = NULL, *group = NULL, *offset = NULL;
     gchar *timestring;
     gint msl, num_timeslices = 0, i, j;
@@ -1380,7 +1375,7 @@ read_cache_file(plugin_data *data)
     CACHE_READ_STRING(timestring, "cache_date");
     cache_date_t = parse_timestring(timestring, NULL, FALSE);
     g_free(timestring);
-    if (difftime(now_t, cache_date_t) > data->cache_file_max_age) {
+    if (difftime(time(NULL), cache_date_t) > data->cache_file_max_age) {
         weather_debug("Cache file is too old and will not be used.");
         CACHE_FREE_VARS();
         return;
@@ -1456,7 +1451,7 @@ read_cache_file(plugin_data *data)
     else {
         weather_debug("Astrodata of the day not in cache. Downloading scheduled in 30s.");
         data->astro_update->attempt = 0;
-        data->astro_update->next = now_t += 30;
+        data->astro_update->next += 30;
         schedule_next_wakeup(data);
     }
     g_free(group);
@@ -1777,12 +1772,16 @@ xfceweather_dialog_response(GtkWidget *dlg,
     } else {
         /* free stuff used in config dialog */
         gtk_widget_destroy(dlg);
+        g_object_unref(dialog->builder);
         gtk_list_store_clear(dialog->model_datatypes);
         for (i = 0; i < dialog->icon_themes->len; i++) {
             theme = g_array_index(dialog->icon_themes, icon_theme *, i);
             icon_theme_free(theme);
         }
         g_array_free(dialog->icon_themes, FALSE);
+        if (dialog->timer_id != 0) {
+            g_source_remove(dialog->timer_id);
+        }
         g_slice_free(xfceweather_dialog, dialog);
 
         xfce_panel_plugin_unblock_menu(data->plugin);
