@@ -93,6 +93,20 @@ typedef struct {
     guint http_status_code;
 } update_info;
 
+typedef enum {
+    ASTRO_DWNLD_SUN = 0,
+    ASTRO_DWNLD_MOON
+} dwnld_state;
+
+typedef struct {
+    guint sun_msg_processed;
+    guint moon_msg_processed;
+    guint sun_msg_parse_error;
+    guint moon_msg_parse_error;
+    dwnld_state astro_dwnld_state;
+    gboolean http_msg_fail;
+} parse_info;
+
 typedef struct {
     XfcePanelPlugin *plugin;
     XfconfChannel *channel;
@@ -130,6 +144,7 @@ typedef struct {
     update_info *astro_update;
     update_info *weather_update;
     update_info *conditions_update;
+    parse_info *msg_parse;
     time_t next_wakeup;
     gchar *next_wakeup_reason;
     guint update_timer;
@@ -191,11 +206,9 @@ void update_weatherdata_with_reset(plugin_data *data);
 
 GArray *labels_clear(GArray *array);
 
-#if LIBXFCE4PANEL_CHECK_VERSION(4,9,0)
 gboolean xfceweather_set_mode(XfcePanelPlugin *panel,
                               XfcePanelPluginMode mode,
                               plugin_data *data);
-#endif
 
 G_END_DECLS
 
